# pymemc

pymemc is a python binary memcached client.

## Why another memcache client?
    * uses the binary protocol
    * 100% native python
    * full featured (all mc functions supported w/ multi-equivalents)
    * tests

## Performance Comparison?
    * TODO (local + across net)


